==> speakeasy-1.0.0.tar.gz: speakeasy/js/speakeasy.js <==
(function (Drupal, drupalSettings, once) {
  Drupal.behaviors.speakeasy = {
    attach: function (context, settings) {
      once('speakeasy', '.speakeasy-container', context).forEach(function (element) {
        const outputStyle = drupalSettings.speakeasy.outputStyle || 'default';

        if (!window.speechSynthesis) {
          alert('Sorry, your browser does not support speech synthesis.');
          return;
        }

        const synth = window.speechSynthesis;
        let voices = [];
        let utteranceQueue = [];
        let currentUtteranceIndex = 0;
        let isSpeaking = false;

        const loadVoices = () => {
          voices = synth.getVoices();
          const voiceSelect = element.querySelector('#speakeasy-voice-select');
          if (voiceSelect && voices.length > 0) {
            voiceSelect.innerHTML = '';
            voices.forEach((voice) => {
              const option = document.createElement('option');
              option.value = voice.name;
              option.textContent = `${voice.name} (${voice.lang})`;
              voiceSelect.appendChild(option);
            });

            const defaultVoiceName = drupalSettings.speakeasy.voiceName;
            if (defaultVoiceName) {
              voiceSelect.value = defaultVoiceName;
            }
          }
        };

        if (synth.onvoiceschanged !== undefined) {
          synth.onvoiceschanged = loadVoices;
        }
        loadVoices();

        const getSelectedVoice = () => {
          const voiceSelect = element.querySelector('#speakeasy-voice-select');
          const selectedVoiceName = voiceSelect ? voiceSelect.value : drupalSettings.speakeasy.voiceName;
          return selectedVoiceName ? voices.find(voice => voice.name === selectedVoiceName) : null;
        };

        const getRate = () => {
          const rateInput = element.querySelector('#speakeasy-rate');
          return rateInput ? parseFloat(rateInput.value) || 1 : parseFloat(drupalSettings.speakeasy.rate) || 1;
        };

        const getPitch = () => {
          const pitchInput = element.querySelector('#speakeasy-pitch');
          return pitchInput ? parseFloat(pitchInput.value) || 1 : parseFloat(drupalSettings.speakeasy.pitch) || 1;
        };

        const createUtterances = (text) => {
          const sentences = text.match(/[^.!?]+[.!?]+[\])'"`’”]*|.+$/g);
          utteranceQueue = sentences.map(sentence => {
            const utterance = new SpeechSynthesisUtterance(sentence.trim());
            utterance.rate = getRate();
            utterance.pitch = getPitch();
            utterance.voice = getSelectedVoice();
            return utterance;
          });
        };

        const speakQueue = () => {
          if (currentUtteranceIndex < utteranceQueue.length) {
            const utterance = utteranceQueue[currentUtteranceIndex];

            utterance.voice = getSelectedVoice();
            utterance.rate = getRate();
            utterance.pitch = getPitch();

            utterance.onend = () => {
              currentUtteranceIndex++;
              speakQueue();
            };

            synth.speak(utterance);
          } else {
            isSpeaking = false;
            currentUtteranceIndex = 0;
            utteranceQueue = [];
          }
        };

        const updateLinkState = () => {
          const link = document.getElementById('speakeasy-link');
          if (link) {
            if (isSpeaking) {
              link.textContent = 'Stop Listening';
            } else {
              link.textContent = 'Listen';
            }
            link.classList.toggle('speaking', isSpeaking);
          }
        };

        if (outputStyle === 'media_player') {
          const playButton = element.querySelector('#speakeasy-play-button');
          const pauseButton = element.querySelector('#speakeasy-pause-button');
          const stopButton = element.querySelector('#speakeasy-stop-button');
          const settingsToggle = element.querySelector('#speakeasy-settings-toggle');
          const settingsContainer = element.querySelector('#speakeasy-settings');

          if (settingsToggle && settingsContainer) {
            settingsToggle.addEventListener('click', function () {
              settingsContainer.style.display = (settingsContainer.style.display === 'none') ? 'block' : 'none';
            });
          }

          if (playButton) {
            playButton.addEventListener('click', function () {
              if (isSpeaking && synth.paused) {
                synth.resume();
              } else if (!isSpeaking) {
                const contentElement = document.querySelector(drupalSettings.speakeasy.contentSelector);
                if (!contentElement || !contentElement.innerText.trim()) {
                  alert('No content available to read.');
                  return;
                }

                createUtterances(contentElement.innerText);
                isSpeaking = true;
                currentUtteranceIndex = 0;
                synth.cancel();
                speakQueue();
              }
            });
          }

          if (pauseButton) {
            pauseButton.addEventListener('click', function () {
              if (synth.speaking && !synth.paused) {
                synth.pause();
              } else if (synth.paused) {
                synth.resume();
              }
            });
          }

          if (stopButton) {
            stopButton.addEventListener('click', function () {
              if (synth.speaking || isSpeaking) {
                synth.cancel();
                isSpeaking = false;
                currentUtteranceIndex = 0;
                utteranceQueue = [];
              }
            });
          }
        } else if (outputStyle === 'default') {
          const ttsButton = element.querySelector('#speakeasy-tts-button');
          const stopButton = element.querySelector('#speakeasy-stop-button');

          if (ttsButton) {
            ttsButton.addEventListener('click', function () {
              if (!isSpeaking) {
                const contentElement = document.querySelector(drupalSettings.speakeasy.contentSelector);
                if (!contentElement || !contentElement.innerText.trim()) {
                  alert('No content available to read.');
                  return;
                }

                createUtterances(contentElement.innerText);
                isSpeaking = true;
                currentUtteranceIndex = 0;
                synth.cancel();
                speakQueue();
              }
            });
          }

          if (stopButton) {
            stopButton.addEventListener('click', function () {
              if (synth.speaking || isSpeaking) {
                synth.cancel();
                isSpeaking = false;
                currentUtteranceIndex = 0;
                utteranceQueue = [];
              }
            });
          }
        } else if (outputStyle === 'simple_link') {
          const link = document.getElementById('speakeasy-link');
          if (link) {
            link.addEventListener('click', function (e) {
              e.preventDefault();
              if (isSpeaking) {
                synth.cancel();
                isSpeaking = false;
                currentUtteranceIndex = 0;
                utteranceQueue = [];
                updateLinkState();
              } else {
                const contentElement = document.querySelector(drupalSettings.speakeasy.contentSelector);
                if (!contentElement || !contentElement.innerText.trim()) {
                  alert('No content available to read.');
                  return;
                }

                createUtterances(contentElement.innerText);
                isSpeaking = true;
                currentUtteranceIndex = 0;
                synth.cancel();
                speakQueue();
                updateLinkState();
              }
            });
          }
        }

        // Stop speech on page unload
        window.addEventListener('pagehide', function () {
          if (synth.speaking) {
            synth.cancel();
          }
        });

        window.addEventListener('beforeunload', function () {
          if (synth.speaking) {
            synth.cancel();
          }
        });
      });
    }
  };
})(Drupal, drupalSettings, once);

==> speakeasy-1.0.1.tar.gz: speakeasy/js/speakeasy.js <==
(function (Drupal, drupalSettings, once) {
  Drupal.behaviors.speakeasy = {
    attach: function (context, settings) {
      once('speakeasy', '.speakeasy-container', context).forEach(function (element) {
        const outputStyle = drupalSettings.speakeasy.outputStyle || 'default';

        if (!window.speechSynthesis) {
          alert('Sorry, your browser does not support speech synthesis.');
          return;
        }

        const synth = window.speechSynthesis;
        let voices = [];
        let utteranceQueue = [];
        let currentUtteranceIndex = 0;
        let isSpeaking = false;

        const loadVoices = () => {
          voices = synth.getVoices();
          const voiceSelect = element.querySelector('#speakeasy-voice-select');
          if (voiceSelect && voices.length > 0) {
            voiceSelect.innerHTML = '';
            voices.forEach((voice) => {
              const option = document.createElement('option');
              option.value = voice.name;
              option.textContent = `${voice.name} (${voice.lang})`;
              voiceSelect.appendChild(option);
            });

            const defaultVoiceName = drupalSettings.speakeasy.voiceName;
            if (defaultVoiceName) {
              voiceSelect.value = defaultVoiceName;
            }
          }
        };

        if (synth.onvoiceschanged !== undefined) {
          synth.onvoiceschanged = loadVoices;
        }
        loadVoices();

        const getSelectedVoice = () => {
          const voiceSelect = element.querySelector('#speakeasy-voice-select');
          const selectedVoiceName = voiceSelect ? voiceSelect.value : drupalSettings.speakeasy.voiceName;
          return selectedVoiceName ? voices.find(voice => voice.name === selectedVoiceName) : null;
        };

        const getRate = () => {
          const rateInput = element.querySelector('#speakeasy-rate');
          return rateInput ? parseFloat(rateInput.value) || 1 : parseFloat(drupalSettings.speakeasy.rate) || 1;
        };

        const getPitch = () => {
          const pitchInput = element.querySelector('#speakeasy-pitch');
          return pitchInput ? parseFloat(pitchInput.value) || 1 : parseFloat(drupalSettings.speakeasy.pitch) || 1;
        };

        const createUtterances = (text) => {
          // Split text into sentences.
          const sentences = text.match(/[^.!?]+[.!?]+[\])'"`’”]*|.+$/g);
          utteranceQueue = sentences.map(sentence => {
            const utterance = new SpeechSynthesisUtterance(sentence.trim());
            utterance.rate = getRate();
            utterance.pitch = getPitch();
            utterance.voice = getSelectedVoice();
            return utterance;
          });
        };

        const speakQueue = () => {
          if (currentUtteranceIndex < utteranceQueue.length) {
            const utterance = utteranceQueue[currentUtteranceIndex];

            utterance.voice = getSelectedVoice();
            utterance.rate = getRate();
            utterance.pitch = getPitch();

            utterance.onend = () => {
              currentUtteranceIndex++;
              speakQueue();
            };

            synth.speak(utterance);
          } else {
            isSpeaking = false;
            currentUtteranceIndex = 0;
            utteranceQueue = [];
          }
        };

        const updateLinkState = () => {
          const link = document.getElementById('speakeasy-link');
          if (link) {
            if (isSpeaking) {
              link.textContent = 'Stop Listening';
            } else {
              link.textContent = 'Listen';
            }
            link.classList.toggle('speaking', isSpeaking);
          }
        };

        if (outputStyle === 'media_player') {
          const playButton = element.querySelector('#speakeasy-play-button');
          const pauseButton = element.querySelector('#speakeasy-pause-button');
          const stopButton = element.querySelector('#speakeasy-stop-button');
          const settingsToggle = element.querySelector('#speakeasy-settings-toggle');
          const settingsContainer = element.querySelector('#speakeasy-settings');

          if (settingsToggle && settingsContainer) {
            settingsToggle.addEventListener('click', function () {
              settingsContainer.style.display = (settingsContainer.style.display === 'none') ? 'block' : 'none';
            });
          }

          if (playButton) {
            playButton.addEventListener('click', function () {
              if (isSpeaking && synth.paused) {
                synth.resume();
              } else if (!isSpeaking) {
                const contentText = drupalSettings.speakeasy.content;
                if (!contentText) {
                  alert('No content available to read.');
                  return;
                }

                createUtterances(contentText);
                isSpeaking = true;
                currentUtteranceIndex = 0;
                synth.cancel();
                speakQueue();
              }
            });
          }

          if (pauseButton) {
            pauseButton.addEventListener('click', function () {
              if (synth.speaking && !synth.paused) {
                synth.pause();
              } else if (synth.paused) {
                synth.resume();
              }
            });
          }

          if (stopButton) {
            stopButton.addEventListener('click', function () {
              if (synth.speaking || isSpeaking) {
                synth.cancel();
                isSpeaking = false;
                currentUtteranceIndex = 0;
                utteranceQueue = [];
              }
            });
          }
        } else if (outputStyle === 'default') {
          const ttsButton = element.querySelector('#speakeasy-tts-button');
          const stopButton = element.querySelector('#speakeasy-stop-button');

          if (ttsButton) {
            ttsButton.addEventListener('click', function () {
              if (!isSpeaking) {
                const contentText = drupalSettings.speakeasy.content;
                if (!contentText) {
                  alert('No content available to read.');
                  return;
                }

                createUtterances(contentText);
                isSpeaking = true;
                currentUtteranceIndex = 0;
                synth.cancel();
                speakQueue();
              }
            });
          }

          if (stopButton) {
            stopButton.addEventListener('click', function () {
              if (synth.speaking || isSpeaking) {
                synth.cancel();
                isSpeaking = false;
                currentUtteranceIndex = 0;
                utteranceQueue = [];
              }
            });
          }
        } else if (outputStyle === 'simple_link') {
          const link = document.getElementById('speakeasy-link');
          if (link) {
            link.addEventListener('click', function (e) {
              e.preventDefault();
              if (isSpeaking) {
                synth.cancel();
                isSpeaking = false;
                currentUtteranceIndex = 0;
                utteranceQueue = [];
                updateLinkState();
              } else {
                const contentText = drupalSettings.speakeasy.content;
                if (!contentText) {
                  alert('No content available to read.');
                  return;
                }

                createUtterances(contentText);
                isSpeaking = true;
                currentUtteranceIndex = 0;
                synth.cancel();
                speakQueue();
                updateLinkState();
              }
            });
          }
        }

        // Stop speech on page unload
        window.addEventListener('pagehide', function () {
          if (synth.speaking) {
            synth.cancel();
          }
        });

        window.addEventListener('beforeunload', function () {
          if (synth.speaking) {
            synth.cancel();
          }
        });
      });
    }
  };
})(Drupal, drupalSettings, once);
